#############################
#lines starting with '#' are comments
#############################

## send the network 'Egonet' from visone to r via the R console

ls() # lists all variables in the workspace
class(Egonet) # prints the class of the 'Egonet' variable (it is 'igraph')

summary(Egonet) # prints summary information (e.g., available attributes)

####################################
## exploring attributes

# show names of vertex and edge attributes
list.vertex.attributes(Egonet)
list.edge.attributes(Egonet)

## see the distribution of attributes
V(Egonet) # vertex iterator (outputs just the vertex indices from 1 to 45)
V(Egonet)$Afrm # countries of origin of the actors
from <-as.factor(V(Egonet)$Afrm) # save countries of origin as a factor
summary(from) # summarize (print number of alters per country of origin)
city <- as.factor(V(Egonet)$Acit) # city of residence
rel.type <- as.factor(V(Egonet)$Arel) # type of relationship to ego

# cross-tabulation
tapply(rel.type, city, summary) 

####################################
## basic descriptive analysis with centralities

#compute and display degree
d <- degree(Egonet)
d
summary(d)
table(d)

# degree distribution by country of origin
tapply(d, from, summary)
tapply(d, from, table)


####################################
## attach values to vertices and load the network into visone

V(Egonet)$log.degree <- log(d) # logarithmized degree
## load Egonet into visone via the 'load' button in the R console


####################################
##vertex and edge iterators in igraph

#select all actors from the US
actors.from.usa <- V(Egonet)[Afrm  == "United States"]
actors.from.usa
# edges within usa
edges.within.usa <- E(Egonet)[actors.from.usa %--% actors.from.usa]
edges.within.usa
# edges with at least one actor from USA
edges.incident.usa <- E(Egonet)[adj(actors.from.usa)]
edges.incident.usa 

##select all edges within classes defined by Afrm
el <- get.edgelist(Egonet) +1 # +1 because edge ids start with zero
# create logical vector for edges
within.class <- V(Egonet)[el[,1]]$Afrm == V(Egonet)[el[,2]]$Afrm
E(Egonet)[within.class]

#########################################
## use ergm package for statistical modeling

## install some packages from statnet
install.packages("network", lib = "C:/juergen/software/visone/R", repos = "http://cran.rakanu.com")
library(network, lib.loc = "C:/juergen/software/visone/R")
install.packages("sna", lib = "C:/juergen/software/visone/R", repos = "http://cran.rakanu.com")
library(sna, lib.loc = "C:/juergen/software/visone/R")
install.packages("ergm", lib = "C:/juergen/software/visone/R", repos = "http://cran.rakanu.com")
library(ergm, lib.loc = "C:/juergen/software/visone/R")

##convert Egonet to the network package
adj <- get.adjacency(Egonet)
net <- as.network(adj, directed=FALSE)
set.vertex.attribute(net,"From", V(Egonet)$Afrm)
set.vertex.attribute(net,"City", V(Egonet)$Acit)

#conversely create an igraph from an adjacency matrix by
# graph.adjacency(adj, mode="undirected")

## summary methods in ergm
summary(net ~ triangle) # number of triangles

# compare to expected number of triangles
p <- 190/choose(45,2)# edge probability
triag.expected <- p^3*choose(45,3)
triag.expected

##examples of an ERGM

model <- ergm(net ~ edges + nodematch("From") + nodematch("City") + gwesp(0.1, fixed=TRUE), MCMCsamplesize=20000) # it takes a while to estimate this model

# print basic information about this model, including parameter estimates
summary(model) 
